******
Mopidy
******

Mopidy is a music server which can play music both from multiple sources, like
your local hard drive, radio streams, and from Spotify and SoundCloud. Searches
combines results from all music sources, and you can mix tracks from all
sources in your play queue. Your playlists from Spotify or SoundCloud are also
available for use.

To control your Mopidy music server, you can use one of Mopidy's web clients,
the Ubuntu Sound Menu, any device on the same network which can control UPnP
MediaRenderers, or any MPD client. MPD clients are available for many
platforms, including Windows, OS X, Linux, Android and iOS.

To get started with Mopidy, check out `the docs <http://docs.mopidy.com/>`_.

- `Documentation <http://docs.mopidy.com/>`_
- `Source code <https://github.com/mopidy/mopidy>`_
- `Issue tracker <https://github.com/mopidy/mopidy/issues>`_
- `CI server <https://travis-ci.org/mopidy/mopidy>`_
- `Download development snapshot <https://github.com/mopidy/mopidy/tarball/develop#egg=mopidy-dev>`_

- IRC: ``#mopidy`` at `irc.freenode.net <http://freenode.net/>`_
- Mailing list: `mopidy@googlegroups.com <https://groups.google.com/forum/?fromgroups=#!forum/mopidy>`_
- Twitter: `@mopidy <https://twitter.com/mopidy/>`_

.. image:: https://pypip.in/v/Mopidy/badge.png
    :target: https://pypi.python.org/pypi/Mopidy/
    :alt: Latest PyPI version

.. image:: https://pypip.in/d/Mopidy/badge.png
    :target: https://pypi.python.org/pypi/Mopidy/
    :alt: Number of PyPI downloads

.. image:: https://travis-ci.org/mopidy/mopidy.png?branch=develop
    :target: https://travis-ci.org/mopidy/mopidy
    :alt: Travis CI build status

.. image:: https://coveralls.io/repos/mopidy/mopidy/badge.png?branch=develop
   :target: https://coveralls.io/r/mopidy/mopidy?branch=develop
   :alt: Test coverage
